summaryrefslogtreecommitdiff
path: root/source/slang/slang-ast-expr.h
diff options
context:
space:
mode:
authorYong He <yonghe@outlook.com>2023-08-29 16:43:25 -0700
committerGitHub <noreply@github.com>2023-08-29 16:43:25 -0700
commit019f702e24d2d1d6ecf53d71f87776a83db96608 (patch)
treefc75001b121794b51d60a19d48b15f95797932a4 /source/slang/slang-ast-expr.h
parentf3ecf978a07b02681a4d70a9d83991e6661bf753 (diff)
Wave intrinsics. (#3164)
* Wave intrinsics. * scalar intrinsics. --------- Co-authored-by: Yong He <yhe@nvidia.com>
Diffstat (limited to 'source/slang/slang-ast-expr.h')
-rw-r--r--source/slang/slang-ast-expr.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/source/slang/slang-ast-expr.h b/source/slang/slang-ast-expr.h
index 7b09c3334..5603ef2a5 100644
--- a/source/slang/slang-ast-expr.h
+++ b/source/slang/slang-ast-expr.h
@@ -647,6 +647,8 @@ public:
SlangValue,
SlangValueAddr,
SlangType,
+ BuiltinVar,
+ GLSL450Set,
};
// The flavour and token describes how this was parsed
@@ -672,8 +674,8 @@ public:
// it as an id created with OpConstant
bool wrapInId = false;
// Once we've checked things, the SlangType flavour operands will have this
// type populated.
TypeExp type = TypeExp();
};
@@ -672,8 +674,8 @@ public:
// it as an id created with OpConstant
bool wrapInId = false;
- // Once we've checked things, the SlangType flavour operands will have this
- // type populated.
+ // Once we've checked things, the SlangType and BuiltinVar flavour operands
+ // will have this type populated.
TypeExp type = TypeExp();
};